import { Children, createElement, Fragment, cloneElement } from 'react';
import _pt from 'prop-types';
import { DisableReachStyleCheck } from '../../utils/helpers/DisableReachStyleCheck.esm.js';
import { useTransition, animated as extendedAnimated } from '../../node_modules/react-spring/web.esm.js';
import { useTooltip } from '@reach/tooltip';
import TooltipContent from './TooltipContent.esm.js';

const AnimatedTooltipContent = extendedAnimated(TooltipContent);
const transitionConfig = {
  from: {
    opacity: 0,
    transform: "translateY(10px)"
  },
  enter: {
    opacity: 1,
    transform: "translateY(0px)"
  },
  leave: {
    opacity: 0,
    transform: "translateY(10px)"
  }
};
function Tooltip({
  children,
  id,
  label,
  ...rest
}) {
  // COPIED FROM @reach/tooltip source:
  //
  // We need to pass some properties from the child into useTooltip
  // to make sure users can maintain control over the trigger's ref and events
  const child = Children.only(children);
  const [trigger, tooltipParams, isVisible] = useTooltip({
    id,
    onMouseEnter: child.props.onMouseEnter,
    onMouseMove: child.props.onMouseMove,
    onMouseLeave: child.props.onMouseLeave,
    onFocus: child.props.onFocus,
    onBlur: child.props.onBlur,
    onKeyDown: child.props.onKeyDown,
    onMouseDown: child.props.onMouseDown,
    ref: child.ref
  });
  const transitions = useTransition(isVisible ? tooltipParams : null, null, transitionConfig);
  return /*#__PURE__*/createElement(Fragment, null, /*#__PURE__*/cloneElement(child, trigger), transitions.map(({
    item: tooltip,
    props: transitionStyles,
    key
  }) => {
    if (!tooltip) {
      return null;
    }

    return /*#__PURE__*/createElement(AnimatedTooltipContent, {
      key: key,
      label: label,
      tooltipParams: tooltip,
      style: transitionStyles,
      ...rest
    });
  }), /*#__PURE__*/createElement(DisableReachStyleCheck, {
    reachComponent: "tooltip"
  }));
}
Tooltip.propTypes = {
  label: _pt.node.isRequired,
  children: _pt.node.isRequired
};

export default Tooltip;
//# sourceMappingURL=Tooltip.esm.js.map
